@@ -4,8 +4,7 @@ from json import dumps
 from json import load
 from os import environ
 from os.path import getsize
-from os.path import join
-from os.path import split
+from pathlib import Path
 from re import match
 from sys import stderr
 from typing import Callable
@@ -27,7 +26,6 @@ from .__version__ import __version__
 from .commands import latest_version
 from .commands import make_journal
 from .commands import make_submission
-from .commands import move_files_folder
 from .commands import print_items
 from .commands import print_users
 from .commands import search
@@ -56,7 +54,7 @@ def check_process(process: str):
     ps: int = 0
     for p in process_iter():
         try:
-            ps += "python" in p.name().lower() and any(process in split(cmd) for cmd in p.cmdline())
+            ps += "python" in p.name().lower() and any(process in Path(cmd).parts for cmd in p.cmdline())
         except (NoSuchProcess, AccessDenied):
             pass
         if ps > 1:
@@ -252,8 +250,9 @@ def config_files_folder(db: FADatabase, *args: str):
     if not args:
         print("files folder:", db.settings["FILESFOLDER"])
     elif len(args) == 1:
-        move_files_folder(db.settings["FILESFOLDER"], args[0])
-        db.settings["FILESFOLDER"] = args[0]
+        print(f"Moving files folder to {args[0]}")
+        db.move_files_folder(args[0])
+        print("Done")
     else:
         raise MalformedCommand("files-folder needs one argument")
 
@@ -981,11 +980,12 @@ def console(comm: str = "", *args: str) -> None:
         print(f"Using FALOCALREPO_DEBUG", file=stderr)
 
     # Initialise and prepare database
-    database_path = "FA.db"
+    database_path: Path = Path("FA.db")
 
     if db_path := environ.get("FALOCALREPO_DATABASE", None):
+        db_path = Path(db_path)
         print(f"Using FALOCALREPO_DATABASE: {db_path}", file=stderr)
-        database_path = db_path if db_path.endswith(".db") else join(db_path, database_path)
+        database_path = db_path if db_path.name.endswith(".db") else db_path / database_path
 
     db: FADatabase = FADatabase(database_path)
     check_database_connections(db)
